<?php

/*
 * Load Field API functions. There could be a lot of these..
 */
require_once 'includes/field.inc';

/**
 * Implements hook_html_head_alter().
 */
function grumpymonkey_html_head_alter(&$head_elements) {
  // Add meta to rescale content apropriately on smaller devices.
  $meta = array(
    '#type' => 'html_tag',
    '#tag' => 'meta',
    '#attributes' => array(
      'name' => 'viewport',
      'content' => 'initial-scale=1.0, width=device-width',
      ),
  );
  $head_elements['grumpymonkey_meta'] = $meta;
}

/**
 * Implements hook_process_HOOK().
 *
 * Borrowed from html5_tools.
 * I didn't want to include a dependency on a module.
 * We'll see whether that was a good decision.
 */
function grumpymonkey_process_html(&$variables) {
  $variables['rdf_header'] = '';
  $variables['rdf_profile'] = '';
  // Support RDF is it's enabled.
  if (module_exists('rdf')) {
    $variables['rdf_header'] = ' PUBLIC "-//W3C//DTD HTML+RDFa 1.1//EN"';
    $variables['rdf_profile'] = ' profile="' . $variables['grddl_profile'].'"';
  }

  drupal_add_http_header('X-UA-Compatible', 'IE=Edge,chrome=1');

  // We do not check for the html5_tools_override_doctype to allow other themes to also
  // use the $html5shiv variable in their html.tpl.php
  $element = array(
    'element' => array(
      '#tag' => 'script',
      '#value' => '',
      '#attributes' => array(
        'src' => file_create_url(drupal_get_path('theme', 'grumpymonkey') . '/js/html5.js'),
      ),
    ),
  );
  $script = theme('html_tag', $element);
  // I really want to keep the mark-up clean, which is why I added the \n
  $variables['html5shiv'] = "\n<!--[if lt IE 9]>\n" . $script . "<![endif]-->\n";
}

/**
 * Implements theme_preprocess_page().
 */
function grumpymonkey_preprocess_page(&$variables) {
  // Check for a logo.
  // We're not supplying one with the theme, so looking for a Drupal one.
  if (strpos($variables['logo'], 'grumpymonkey/logo.png') !== FALSE) {
    $variables['logo'] = '/themes/bartik/logo.png';
    $variables['logo_classes'] = 'drupal';
  }
}

/**
 * Implements theme_process_page().
 */
function grumpymonkey_process_page(&$variables) {

}

/**
 * Returns HTML for a list or nested list of items.
 *
 * @param $variables
 *   An associative array containing:
 *   - items: An array of items to be displayed in the list. If an item is a
 *     string, then it is used as is. If an item is an array, then the "data"
 *     element of the array is used as the contents of the list item. If an item
 *     is an array with a "children" element, those children are displayed in a
 *     nested list. All other elements are treated as attributes of the list
 *     item element.
 *   - title: The title of the list.
 *   - type: The type of list to return (e.g. "ul", "ol").
 *   - attributes: The attributes applied to the list element.
 *
 * Cleanup by removing unnecessary wrapper div.
 */
function grumpymonkey_item_list($variables) {
  $items = $variables['items'];
  $title = $variables['title'];
  $type = $variables['type'];
  $attributes = $variables['attributes'];
  $output = '';

  if (isset($title)) {
    $output .= '<h3>' . $title . '</h3>';
  }

  if (!empty($items)) {
    $output .= "<$type" . drupal_attributes($attributes) . '>';
    $num_items = count($items);
    foreach ($items as $i => $item) {
      $attributes = array();
      $children = array();
      $data = '';
      if (is_array($item)) {
        foreach ($item as $key => $value) {
          if ($key == 'data') {
            $data = $value;
          }
          elseif ($key == 'children') {
            $children = $value;
          }
          else {
            $attributes[$key] = $value;
          }
        }
      }
      else {
        $data = $item;
      }
      if (count($children) > 0) {
        // Render nested list.
        $data .= theme_item_list(array('items' => $children, 'title' => NULL, 'type' => $type, 'attributes' => $attributes));
      }
      if ($i == 0) {
        $attributes['class'][] = 'first';
      }
      if ($i == $num_items - 1) {
        $attributes['class'][] = 'last';
      }
      $output .= '<li' . drupal_attributes($attributes) . '>' . $data . "</li>\n";
    }
    $output .= "</$type>";
  }
  return $output;
}

/**
 * Implements hook_js_alter().
 */
function grumpymonkey_css_alter(&$css) {
  if (user_is_anonymous()) {
    $path_to_theme = path_to_theme();
    $allowed_css = array(
      // Empty for now.
    );
    foreach ($css as $key => $script) {
      if (!is_numeric($key) && !in_array($key, $allowed_css) && strpos($key, $path_to_theme) === FALSE) {
        unset($css[$key]);
      }
    }
  }
}

/**
 * Implements hook_js_alter().
 */
function grumpymonkey_js_alter(&$js) {
  if (user_is_anonymous()) {
    $path_to_theme = path_to_theme();
    $allowed_js = array(
      // Empty for now. Some examples are:
      // 'settings',
      // 'misc/jquery.js',
      // 'sites/all/modules/contrib/google_analytics/googleanalytics.js',
    );
    foreach ($js as $key => $script) {
      if (!is_numeric($key) && !in_array($key, $allowed_js) && strpos($key, $path_to_theme) === FALSE) {
        unset($js[$key]);
      }
    }
  }
}